@@ -1,5 +1,6 @@
 from tempfile import gettempdir
 import os
+import re
 import mimetypes
 
 mimetypes.init()
@@ -38,3 +39,12 @@ MONTH_FULLNAME_INDEX = 1
 
 ENGLISH_INDEX = 0
 DUTCH_INDEX = 1
+
+TAGS_TO_REMOVE = re.compile(r'<[^>]+>')
+REPLACE_DICT = {
+    "<em>": "<italic = \"On\">",
+    "</em>": "<italic = \"Off\">",
+    "<b>": "<bold = \"On\">",
+    "</b>": "<bold = \"Off\">",
+    u'\xa0': ""
+}
